@@ -1,10 +1,9 @@
 package rules
 
 import (
-	regexp "github.com/wasilibs/go-re2"
-
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/config"
+	"github.com/zricethezav/gitleaks/v8/regexp"
 )
 
 func PrivateKey() *config.Rule {
@@ -21,7 +20,7 @@ func PrivateKey() *config.Rule {
 anything
 -----END PRIVATE KEY-----`,
 		`-----BEGIN RSA PRIVATE KEY-----
-abcdefghijklmnopqrstuvwxyz
+abcdefghijksmnopqrstuvwxyz
 -----END RSA PRIVATE KEY-----
 `,
 		`-----BEGIN PRIVATE KEY BLOCK-----
