@@ -4,15 +4,11 @@ import (
 	"os"
 	"os/signal"
 
-	"github.com/rs/zerolog"
-	"github.com/rs/zerolog/log"
 	"github.com/zricethezav/gitleaks/v8/cmd"
+	"github.com/zricethezav/gitleaks/v8/logging"
 )
 
 func main() {
-	// send all logs to stdout
-	log.Logger = log.Output(zerolog.ConsoleWriter{Out: os.Stderr})
-
 	// this block sets up a go routine to listen for an interrupt signal
 	// which will immediately exit gitleaks
 	stopChan := make(chan os.Signal, 1)
@@ -24,5 +20,5 @@ func main() {
 
 func listenForInterrupt(stopScan chan os.Signal) {
 	<-stopScan
-	log.Fatal().Msg("Interrupt signal received. Exiting...")
+	logging.Fatal().Msg("Interrupt signal received. Exiting...")
 }
